# chia-blockchain

![Alt text](https://chiadoge.net/assets/img/chiadoge.png)


Chiadogecoin is an open source peer-to-peer digital currency, created by chia project former developer and shiba community,favored by Shiba Inus worldwide.

Chiadogecoin, a digital currency based on an open source, peer-to-peer internet protocol, is created by the former developers of the Chia project in collaboration with Shiba community that globally famous for Shiba Inu. One block of Chiadogecoin is generated in about 10 minutes, and halved in every three years. In the first year, each block generate 20000 Chiadogecoins, and it will be halved to 10000 coins at next third years, this model will run about 30 years and experience 9 halves. From the 31st to 99th year, each block generate constant 50 coins, and after the 100th year, block reward becomes 0. The total amount of Chiadogecoin is finally constant about 200 billion.



## Installing

Install instructions are available in the
[INSTALL](https://github.com/Chiadoge-Network/chiadogecoin/wiki/INSTALL)
section of the
[chia-blockchain repository wiki](https://github.com/Chiadoge-Network/chiadogecoin/wiki).

## RoadMap

The total amount of chiadoge is a constant, almost 200,000,000,000.halving every 3 years,detail see:
[Official website](https://chiadogecoin.com).

## Community

[Twitter](https://twitter.com/chiadogecoin)
[Discord](https://discord.com/invite/qK2x5zFUNx)
[Reddit](https://www.reddit.com/r/chiadogecoin).
[Telegram](https://t.me/chiadogecoin).
